# This syntax definition is for the vfs::mk4 package
# package require vfs::mk4

# The list is far from complete here

set ::syntax(vfs::mk4::Mount) "r 2"
set ::syntax(vfs::unmount) 1

lappend ::knownPackages vfs::mk4
