# Extracted from textutil version 0.8
lappend ::knownPackages textutil
set ::syntax(textutil::adjust) {r 1}
set ::syntax(textutil::adjust::adjust) {r 1}
set ::syntax(textutil::adjust::getPredefined) 1
set ::syntax(textutil::adjust::indent) {r 2 3}
set ::syntax(textutil::adjust::listPredefined) 0
set ::syntax(textutil::adjust::readPatterns) 1
set ::syntax(textutil::adjust::strRepeat) 2
set ::syntax(textutil::adjust::undent) 1
set ::syntax(textutil::blank) 1
set ::syntax(textutil::cap) 1
set ::syntax(textutil::capEachWord) 1
set ::syntax(textutil::chop) 1
set ::syntax(textutil::indent) {r 2 3}
set ::syntax(textutil::longestCommonPrefix) {r 0}
set ::syntax(textutil::longestCommonPrefixList) 1
set ::syntax(textutil::repeat::blank) 1
set ::syntax(textutil::repeat::strRepeat) 2
set ::syntax(textutil::split::splitn) {r 1 2}
set ::syntax(textutil::split::splitx) {r 1 2}
set ::syntax(textutil::splitn) {r 1 2}
set ::syntax(textutil::splitx) {r 1 2}
set ::syntax(textutil::strRepeat) 2
set ::syntax(textutil::string::cap) 1
set ::syntax(textutil::string::capEachWord) 1
set ::syntax(textutil::string::chop) 1
set ::syntax(textutil::string::longestCommonPrefix) {r 0}
set ::syntax(textutil::string::longestCommonPrefixList) 1
set ::syntax(textutil::string::tail) 1
set ::syntax(textutil::string::uncap) 1
set ::syntax(textutil::tabify) {r 1 2}
set ::syntax(textutil::tabify2) {r 1 2}
set ::syntax(textutil::tabify::checkArr) 1
set ::syntax(textutil::tabify::strRepeat) 2
set ::syntax(textutil::tabify::tabify) {r 1 2}
set ::syntax(textutil::tabify::tabify2) {r 1 2}
set ::syntax(textutil::tabify::tabifyLine) 2
set ::syntax(textutil::tabify::untabify) {r 1 2}
set ::syntax(textutil::tabify::untabify2) {r 1 2}
set ::syntax(textutil::tabify::untabifyLine) 2
set ::syntax(textutil::tail) 1
set ::syntax(textutil::trim) {r 1 2}
set ::syntax(textutil::trim::trim) {r 1 2}
set ::syntax(textutil::trim::trimEmptyHeading) 1
set ::syntax(textutil::trim::trimPrefix) 2
set ::syntax(textutil::trim::trimleft) {r 1 2}
set ::syntax(textutil::trim::trimright) {r 1 2}
set ::syntax(textutil::trimEmptyHeading) 1
set ::syntax(textutil::trimPrefix) 2
set ::syntax(textutil::trimleft) {r 1 2}
set ::syntax(textutil::trimright) {r 1 2}
set ::syntax(textutil::uncap) 1
set ::syntax(textutil::undent) 1
set ::syntax(textutil::untabify) {r 1 2}
set ::syntax(textutil::untabify2) {r 1 2}
