# Extracted from profiler version 0.3
lappend ::knownPackages profiler
set ::syntax(profiler::dump) {r 0 1}
set ::syntax(profiler::enterHandler) 2
set ::syntax(profiler::init) 0
set ::syntax(profiler::leaveHandler) 2
set ::syntax(profiler::print) {r 0 1}
set ::syntax(profiler::printname) 1
set ::syntax(profiler::printsorted) {r 1 2}
set ::syntax(profiler::profProc) 3
set ::syntax(profiler::reset) {r 0 1}
set ::syntax(profiler::resume) {r 0 1}
set ::syntax(profiler::sortFunctions) {r 0 1}
set ::syntax(profiler::stats) {r 0}
set ::syntax(profiler::suspend) {r 0 1}
set ::syntax(profiler::tMark) {r 0 1}
set ::syntax(profiler::tZero) {r 0 1}
